# eric7.Plugins.VcsPlugins.vcsMercurial.QueuesExtension.HgQueuesNewPatchDialog

Module implementing a dialog to get the data for a new patch.

### Global Attributes

None

### Classes

HgQueuesNewPatchDialog | Class implementing a dialog to get the data for a new patch.

### Functions

None

## HgQueuesNewPatchDialog

Class implementing a dialog to get the data for a new patch.

### Derived from

QDialog, Ui_HgQueuesNewPatchDialog

### Class Attributes

NEW_MODE
REFRESH_MODE

### Class Methods

None

### Methods

HgQueuesNewPatchDialog | Constructor
__updateUI | Private slot to update the UI.
getData | Public method to retrieve the entered data.
on_currentUserCheckBox_toggled | Private slot to handle changes of the currentuser state.
on_messageEdit_textChanged | Private slot to handle changes of the patch message.
on_nameEdit_textChanged | Private slot to handle changes of the patch name.
on_userEdit_textChanged | Private slot to handle changes of the user name.
on_userGroup_toggled | Private slot to handle changes of the user group state.

### Static Methods

None

#### HgQueuesNewPatchDialog (Constructor)

HgQueuesNewPatchDialog(mode, message="", parent=None)

Constructor

mode
  mode of the dialog (HgQueuesNewPatchDialog.NEW_MODE, HgQueuesNewPatchDialog.REFRESH_MODE)
message
  text to set as the commit message (string)
parent
  reference to the parent widget (QWidget)

Raises ValueError:
  raised to indicate an invalid dialog mode

#### HgQueuesNewPatchDialog.__updateUI

__updateUI()

Private slot to update the UI.

#### HgQueuesNewPatchDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple giving the patch name and message, a tuple giving a flag indicating to set the user, a flag indicating to use the current user and the user name and another tuple giving a flag indicating to set the date, a flag indicating to use the current date and the date (string, string, (boolean, boolean, string), (boolean, boolean, string))

#### HgQueuesNewPatchDialog.on_currentUserCheckBox_toggled

on_currentUserCheckBox_toggled(checked)

Private slot to handle changes of the currentuser state.

checked
  flag giving the checked state (boolean)

#### HgQueuesNewPatchDialog.on_messageEdit_textChanged

on_messageEdit_textChanged()

Private slot to handle changes of the patch message.

#### HgQueuesNewPatchDialog.on_nameEdit_textChanged

on_nameEdit_textChanged(txt)

Private slot to handle changes of the patch name.

txt
  text of the edit (string)

#### HgQueuesNewPatchDialog.on_userEdit_textChanged

on_userEdit_textChanged(txt)

Private slot to handle changes of the user name.

txt
  text of the edit (string)

#### HgQueuesNewPatchDialog.on_userGroup_toggled

on_userGroup_toggled(checked)

Private slot to handle changes of the user group state.

checked
  flag giving the checked state (boolean)

Up